@@ -43,7 +43,7 @@
 #' runs.test(y)
 #' 
 #' 
-`runs.test` <- function(y,
+runs.test <- function(y,
                         plot.it = FALSE,
                         alternative = c("two.sided", "positive.correlated", "negative.correlated"))
 {
